@@ -10,7 +10,7 @@ use HTTP::Cookies;
 use URI;
 use Date::Format;
 
-our $VERSION = '0.93';
+our $VERSION = '0.94';
 
 our $DEBUG = 0;
 
@@ -663,16 +663,14 @@ sub _test {
             # if no op and no $RHS, return pound != test(LHS)
             # if op, and no RHS or no LHS, FAIL
             # if op, do op.. return [pound != test(LHS)] op [test(LHS)]
-            if ($OP)
-                { # LOGICAL COMPARISON && and ||
+            if ($OP) {
+                # LOGICAL COMPARISON && and ||
                     # NOTE:  && and || have equal precedence
 
-                if ($LHS=~/^\s*$/)
-                    {
+                if ($LHS=~/^\s*$/) {
                     return $self->SSI_ERROR("empty logical comparison in expr.");
                     }
-                if ($RHS=~/^\s*$/)
-                    {
+                if ($RHS=~/^\s*$/) {
                     return $self->SSI_ERROR("empty logical comparison in expr.");
                     }
 
@@ -689,12 +687,10 @@ sub _test {
                 else # ($OP eq "||")
                     { return ($LHS || $self->_test($RHS)); } # short circuits, faster
                 }
-            else
-                { # NO OP
-                if ($LHS && $RHS)
-                    {
-                    if ($LHS_parens)
-                        {
+            else {
+                # NO OP
+                if ($LHS && $RHS) {
+                    if ($LHS_parens) {
 #                    	return $self->SSI_ERROR("error in expression."); # NOTE: FIXME: improve this error msg.. 
 #                    	return $self->SSI_ERROR("error in expression. LHS and RHS but no OP"); # NOTE: FIXME: improve this error msg.. 
                         return $self->SSI_ERROR("error in expression. LHS [$LHS] and RHS [$RHS] but no OP"); # NOTE: FIXME: improve this error msg.. 
@@ -715,8 +711,7 @@ sub _test {
                     { $test = $RHS; }  # NOTE: is this redundant?
                 }
             }
-        else
-            {
+        else {
             return $self->SSI_ERROR("unknown error in expression."); # SHOULD NOT REACH THIS
             }
         }
@@ -776,8 +771,7 @@ sub _test {
             elsif ($cmp eq "!=") 
                 { return ($s1 !~ $s2); }	# NOTE: FIXME!!!
             }
-        else
-            {
+        else {
             if ($s2=~m|^[^\s/]+\s+/|) # unquoted, unescaped slash
                 { return $self->SSI_ERROR("problem in REGEX unquoted slash. s2=[$s2]"); }		# NOTE: FIXME
 
@@ -801,8 +795,7 @@ sub _test {
 
         return $ret;
         }
-    else
-        {
+    else {
         if ($test =~ m{[^/]+\s+/})	# NOTE: UNFINISHED!! FIXME non empty unrecognized string that didnt fail
             { return $self->SSI_ERROR("error in expression, regex found in string"); }
         return 1;
@@ -877,15 +870,13 @@ sub if {
 sub elif {
     my($self,$expr,$test) = @_;
     
-    if (! $self->_in_if() )
-        {
+    if (! $self->_in_if() ) {
         $self->SSI_WARN("Incorrect use of elif ssi directive: no preceeding 'if'."); # NOTE: just a "warn"
         $self->_suspend() unless $self->_suspended();  
         return;
         }
 
-    if ($self->_seen_true())
-        {
+    if ($self->_seen_true()) {
         $self->_suspend() unless $self->_suspended();  
         return;
         }
@@ -926,9 +917,7 @@ sub else {
 
 sub endif {
     my $self = shift;
-    if (! $self->_in_if() )
-        {
-        # $self->SSI_ERROR("Incorrect use of endif ssi directive: no preceeding 'if'.");
+    if (! $self->_in_if() ) {
         $self->SSI_WARN("Incorrect use of endif ssi directive: no preceeding 'if'.");
         }
     else
